/*
 * Copyright (c) 2010, 2011 Ryan Vogt <vogt@cs.ualberta.ca>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#include <mp4v2/mp4v2.h>
#include <math.h>
#include <stdio.h>
#include <stdint.h>
#include <time.h>
#include "global.h"

/*
 * The number of seconds between updates of the progress message.
 */
#define PROGRESS_TIME (1)

void printMilliseconds(MP4Duration milliseconds)
{
  MP4Duration h, m, s;
  h = milliseconds / 3600000;
  milliseconds -= h * 3600000;
  m = milliseconds / 60000;
  milliseconds -= m * 60000;
  s = milliseconds / 1000;
  milliseconds -= s * 1000;
  printf("%ju:%02ju:%02ju.%03ju", (uintmax_t)h, (uintmax_t)m, (uintmax_t)s,
	 (uintmax_t)milliseconds);
}

void printSeconds(double seconds)
{
  printMilliseconds((MP4Duration)llround(seconds*1000));
}

void progress(const char *task, uint32_t onTrack, uint32_t numTracks,
	      MP4SampleId done, MP4SampleId total)
{
  static time_t last = 0;
  time_t current = time(NULL);
  double percent;

  if (done != 0 && done != total && current - last < PROGRESS_TIME)
    return;
  last = current;

  if (total != 0)
    percent = ((double)done)/total * 100.0;
  else
    percent = 100.0;
  printf("\r%s %llu/%llu (%.2lf%%)", task, (unsigned long long)onTrack,
	 (unsigned long long)numTracks, percent);
  if (done == total)
    printf("\n");
  fflush(stdout);
}
