/*
 * Copyright (c) 2011 Ryan Vogt <vogt@cs.ualberta.ca>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#include <mp4v2/mp4v2.h>
#include <stdio.h>
#include "global.h"
#include "mp4File.h"

/*
 * Prints the relevant information about a track.
 */
static void printTrack(struct mp4Track *track);

/*
 * Parse the command line options passed to mp4Chapters.
 * inputFile will point to the relevant argument within argv.
 * Return 0 on success, -1 on error (and print an error message).
 */
static int parseCommandLine(int argc, char **argv, char **inputFile);

int main(int argc, char **argv)
{
  char *inputFile;
  uint32_t i;
  struct mp4File *file = NULL;
  int wasErr = 0;

  /* Parse the command line and open the input file */
  if (parseCommandLine(argc, argv, &inputFile))
    ERROR_QUIET(isErr, wasErr);
  file = readFile(inputFile);
  if (file == NULL)
    ERROR_QUIET(isErr, wasErr);

  /* List the tracks in the input file */
  for (i = 0; i < file->numAudio; i++) {
    printf("Audio track %ju:\n", (uintmax_t)(i+1));
    printTrack(file->audio[i]);
  }
  printf("Video track 1:\n");
  printTrack(file->video);

 isErr:
  if (file != NULL)
    closeFile(file);
  return wasErr ? -1 : 0;
}

static void printTrack(struct mp4Track *track)
{
  printf("    Samples: %ju\n", (uintmax_t)(track->numSamples));
  printf("    Ticks per second: %ju\n", (uintmax_t)(track->timeScale));
  printf("    Duration: %ju ticks (", (uintmax_t)(track->duration));
  printSeconds(((double)(track->duration))/(track->timeScale));
  printf(")\n");
}

static int parseCommandLine(int argc, char **argv, char **inputFile)
{
  int wasErr = 0;

  if (argc != 2)
    ERROR(isErr, wasErr, "Usage: %s INPUT_FILE", argv[0]);
  *inputFile = argv[1];

 isErr:
  return wasErr ? -1 : 0;
}
